@@ -295,8 +295,8 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
                     dispatch_usenew = _args.no_questions
         finally:
             wait_thread.stop()
-            sys.stdout.write("\b")
-            sys.stdout.flush()
+            # sys.stdout.write("\b")
+            # sys.stdout.flush()
         client.service.clear_method_cache(client.sid, args.method)
         method_parser.print_help()
     else:
@@ -370,16 +370,16 @@ def main(wait_thread):
 
     if not args.method and args.help:
         wait_thread.stop()
-        sys.stdout.write('\r')
-        sys.stdout.flush()
+        # sys.stdout.write('\r')
+        # sys.stdout.flush()
         parser.print_help()
         return 0
 
     if not args.method:
         if unknown_args:
             wait_thread.stop()
-            sys.stdout.write('\r')
-            sys.stdout.flush()
+            # sys.stdout.write('\r')
+            # sys.stdout.flush()
             args = parser.parse_args(
                 list(unpack_single_opts(sys.argv[1:])))
 
