@@ -259,8 +259,8 @@ class CheckingClientHTTPSConnection(httplib.HTTPSConnection):
                     OpenSSL.SSL.FILETYPE_PEM, cert)
                 Issuer = certobj.get_issuer().get_components()
                 for item in Issuer:
-                    if item[0] == 'CN':
-                        filename = item[1]
+                    if item[0] == b'CN':
+                        filename = item[1].decode("UTF-8")
 
                 fc = open(root_cert_md5, "a")
                 fc.write('%s %s\n' % (md5sum, filename))
@@ -314,7 +314,7 @@ class CheckingClientHTTPSConnection(httplib.HTTPSConnection):
         print('\n', _("Subject"))
         for subj in Subject:
             print("%s : %s" % (subj[0], subj[1]))
-        ans = raw_input(_("Add the CA certificate to trusted? y/[n]:"))
+        ans = input(_("Add the CA certificate to trusted? y/[n]:"))
         if ans.lower() in ['y', 'yes']:
             list_ca_certs.append(cert)
             self.add_all_ca_cert(list_ca_certs)
@@ -340,7 +340,7 @@ class CheckingClientHTTPSConnection(httplib.HTTPSConnection):
 
         print('\n' + _('Add this server certificate to trusted (s) or'))
         print(_('Try to add the CA and root certificates to trusted (c) or'))
-        choice = raw_input(_("Quit (q)? s/c/[q]: "))
+        choice = input(_("Quit (q)? s/c/[q]: "))
         if choice.lower() in ['s', 'c']:
             # self.sock = ssl.wrap_socket(sock)
             ca_certs = os.path.join(self.trusted_path, "cert.list")
